@@ -7,9 +7,12 @@ def test_create_from_corpus(datadir):
 
     result = CorpusPattern.create_from_corpus(corpus)
 
+    docs_len = {len(i.get_docs()) for i in result}
+    assert docs_len == {2, 1}
+
     result_str_list = sorted([str(i) for i in result])
 
-    expected_str_list = sorted(["`PERSON`在`GPE`的`ORG`读书。", "来一首`歌手名`的歌。"])
+    expected_str_list = sorted(["<PERSON>在<GPE>的<ORG>读书。", "来一首<歌手名>的歌。"])
 
     for r, e in zip(result_str_list, expected_str_list):
         assert e in r
