@@ -13,10 +13,12 @@ def test_document_pattern():
             EntityPlaceholder(start=2, end=3, entity="goods"),
         ]
     )
+    dp.label = "LABEL"
 
     # test if render method works
 
     doc = dp.render({"name": ["Real", "Name"], "goods": ["RealGoods"]})
+    assert doc.label == "LABEL"
 
     expected_doc_snippet = "[RealName](name)的[RealGoods](goods)"
     result_doc = str(doc)
