@@ -7,8 +7,7 @@ class BaseEvaluator(object):
     def process_one_batch(self, gold_data, test_data, *args, **kwargs):
         raise NotImplemented
 
-    def get_score(self):
-        # type: () -> Tuple(str, str, str)
+    def get_score(self) -> dict:
         """
 
         :return: (precision, recall, f1)
